.. _components:

Overview
=====================

This is the summary of the available ``earthkit`` components.

.. list-table::
    :widths: 20 60 20
    :header-rows: 1

    * - Component
      - Description
      - Logo
    * - :xref:`earthkit-data`
      - Format-agnostic Python interface for geospatial data with a focus on meteorology and climate science.
      - .. image:: https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-data-light.svg
          :width: 180px
    * - :xref:`earthkit-geo`
      - Geospatial computations.
      - .. image:: https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-geo-light.svg
          :width: 180px
    * - :xref:`earthkit-hydro`
      - Operations on river networks.
      - .. image:: https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-hydro-light.svg
          :width: 180px
    * - :xref:`earthkit-meteo`
      - Meteorological computations.
      - .. image:: https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-meteo-light.svg
          :width: 180px
    * - :xref:`earthkit-plots`
      - Visualisation tools and templates.
      - .. image:: https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-plots-light.svg
          :width: 180px
    * - :xref:`earthkit-regrid`
      - Regridding of geospatial data.
      - .. image:: https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-regrid-light.svg
          :width: 180px
    * - :xref:`earthkit-time`
      - Manipulation of dates and time for weather forecasting.
      - .. image:: https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-time-light.svg
          :width: 180px
    * - :xref:`earthkit-transforms`
      - Aggregation and transformation of geospatial data.
      - .. image:: https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-transforms-light.svg
          :width: 180px
